@@ -1,7 +1,7 @@
 use strict;
 package Dist::Zilla::PluginBundle::Author::MAXHQ;
 # ABSTRACT: MAXHQ's default Dist::Zilla configuration
-$Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '1.000006';
+$Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '1.001000';
 #pod =encoding UTF-8
 #pod  
 #pod =head1 SYNOPSIS
@@ -42,6 +42,7 @@ $Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '1.000006';
 #pod 	minor = +ENHANCEMENTS
 #pod 	revision = REVISION, BUG FIXES, DOCUMENTATION
 #pod 	numify_version = 1
+#pod 	format = %d.%03d%03d
 #pod
 #pod 	[PodWeaver]
 #pod 	config_plugin = @Author::MAXHQ
@@ -56,6 +57,13 @@ $Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '1.000006';
 #pod 	[Prereqs::MatchInstalled::All]
 #pod 	exclude = strict
 #pod 	exclude = warnings
+#pod 	exclude = Dist::Zilla::PluginBundle::Author::MAXHQ
+#pod
+#pod 	[Prereqs / MAXHQ]
+#pod 	-phase = build
+#pod 	-relationship = requires
+#pod 	Pod::Elemental::Transformer::List = 0
+#pod 	Pod::Coverage::TrustPod = 0
 #pod
 #pod 	#
 #pod 	# Auto generation --- distribution files
@@ -164,6 +172,7 @@ sub configure {
 			minor => '+ENHANCEMENTS',
 			revision => 'REVISION, BUG FIXES, DOCUMENTATION',
 			numify_version => 1,          # use x.yyyzzz convention instead of x.y.z
+			format => '%d.%03d%03d',
 		}],
 		# Please note that * and ! are mainly there to enforce correct ordering
 		# as CPAN::Changes::Release (used in NextVersion::Semantic) just sorts
@@ -185,8 +194,15 @@ sub configure {
 		                                  # authordeps" to the 'develop' phase prerequisite list"
 		'PrereqsClean',                   # "Cleans up mess from other Prereq modules"
 		['Prereqs::MatchInstalled::All' => { # adjust prereqs to use same version as currently installed
-			exclude => [qw( strict warnings )]
+			exclude => [qw( strict warnings Dist::Zilla::PluginBundle::Author::MAXHQ )]
 		}],
+		['Prereqs', 'MAXHQ', {            # special prerequisites (name MAXHQ 
+			'-phase' => 'runtime',        # disambiguates the Prereqs plugin in
+			'-relationship' => 'requires',# case it's also specified in users' dist.ini)
+			'Pod::Elemental::Transformer::List' => 0, # not automatically installed with Dist::Zilla
+			'Pod::Coverage::TrustPod' => 0,           # not automatically installed with Dist::Zilla
+		}],
+		
 		
 		#
 		# Auto generation --- distribution files
@@ -236,7 +252,7 @@ Dist::Zilla::PluginBundle::Author::MAXHQ - MAXHQ's default Dist::Zilla configura
 
 =head1 VERSION
 
-version 1.000006
+version 1.001000
 
 =head1 SYNOPSIS
 
@@ -276,6 +292,7 @@ Currently this plugin bundle is equivalent to:
 	minor = +ENHANCEMENTS
 	revision = REVISION, BUG FIXES, DOCUMENTATION
 	numify_version = 1
+	format = %d.%03d%03d
 
 	[PodWeaver]
 	config_plugin = @Author::MAXHQ
@@ -290,6 +307,13 @@ Currently this plugin bundle is equivalent to:
 	[Prereqs::MatchInstalled::All]
 	exclude = strict
 	exclude = warnings
+	exclude = Dist::Zilla::PluginBundle::Author::MAXHQ
+
+	[Prereqs / MAXHQ]
+	-phase = build
+	-relationship = requires
+	Pod::Elemental::Transformer::List = 0
+	Pod::Coverage::TrustPod = 0
 
 	#
 	# Auto generation --- distribution files
@@ -331,7 +355,7 @@ Jens Berthold <jens.berthold@jebecs.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Jens Berthold.
+This software is copyright (c) 2015 by Jens Berthold.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
