@@ -1,7 +1,7 @@
 use strict;
 package Pod::Weaver::PluginBundle::Author::MAXHQ;
 # ABSTRACT: MAXHQ's default Pod::Weaver configuration
-$Pod::Weaver::PluginBundle::Author::MAXHQ::VERSION = '1.000006';
+$Pod::Weaver::PluginBundle::Author::MAXHQ::VERSION = '1.001000';
 # Thanks to
 # - Joshua Keroes (http://rjbs.manxome.org/rubric/entry/1809)
 # - rjbs (http://de.slideshare.net/jkeroes/getting-started-with-podweaver)
@@ -35,18 +35,9 @@ $Pod::Weaver::PluginBundle::Author::MAXHQ::VERSION = '1.000006';
 #pod 	;#
 #pod 	;# functions etc.
 #pod 	;#
-#pod 	[Collect / ATTRIBUTES]
-#pod 	command = attr
+#pod 	[Collect / REX TASKS]
+#pod 	command = rex_task
 #pod
-#pod 	[Collect / REQUIRED METHODS]
-#pod 	command = requires
-#pod 	
-#pod 	[Collect / CLASS METHODS]
-#pod 	command = class_method
-#pod 	
-#pod 	[Collect / METHODS]
-#pod 	command = method
-#pod 	
 #pod 	[Collect / MOJOLICIOUS PLUGINS]
 #pod 	command = mojo_plugin
 #pod 	
@@ -58,6 +49,21 @@ $Pod::Weaver::PluginBundle::Author::MAXHQ::VERSION = '1.000006';
 #pod 	
 #pod 	[Collect / MOJOLICIOUS HELPERS]
 #pod 	command = mojo_helper
+#pod
+#pod 	[Collect / FUNCTIONS ]
+#pod 	command = func
+#pod
+#pod 	[Collect / ATTRIBUTES]
+#pod 	command = attr
+#pod
+#pod 	[Collect / METHODS REQUIRED BY THIS ROLE]
+#pod 	command = requires
+#pod 	
+#pod 	[Collect / CLASS METHODS]
+#pod 	command = class_method
+#pod 	
+#pod 	[Collect / METHODS]
+#pod 	command = method
 #pod 	
 #pod 	
 #pod 	[Leftovers]
@@ -102,22 +108,32 @@ sub mvp_bundle_config {
 		[ '@MAXHQ/Name',           _exp('Name'),             {} ],
 		[ '@MAXHQ/Version',        _exp('Version'),          {} ],
 		
+		# Header
 		[ '@MAXHQ/Prelude',        _exp('Region'),  { region_name => 'prelude'     } ],
 	
 		[ '@MAXHQ/Synopsis',       _exp('Generic'), { header      => 'SYNOPSIS'    } ],
 		[ '@MAXHQ/Description',    _exp('Generic'), { header      => 'DESCRIPTION' } ],
 		[ '@MAXHQ/Overview',       _exp('Generic'), { header      => 'OVERVIEW'    } ],
 	
-		[ '@MAXHQ/Functions',      _exp('Collect'), { command => 'func',         header => ''   } ],
-		[ '@MAXHQ/Attributes',     _exp('Collect'), { command => 'attr',         header => 'ATTRIBUTES'} ],
-		[ '@MAXHQ/RoleRequires',   _exp('Collect'), { command => 'requires',     header => 'REQUIRED METHODS' } ],
-		[ '@MAXHQ/ClassMethods',   _exp('Collect'), { command => 'class_method', header => 'CLASS METHODS' } ],
-		[ '@MAXHQ/Methods',        _exp('Collect'), { command => 'method',       header => 'METHODS' } ],
+		# Rex specific
+		[ '@MAXHQ/RexTasks',       _exp('Collect'), { command => 'rex_task',     header => 'REX TASKS' } ],
+
+		# Mojolicious specific
 		[ '@MAXHQ/MojoPlugins',    _exp('Collect'), { command => 'mojo_plugin',  header => 'MOJOLICIOUS PLUGINS' } ],
 		[ '@MAXHQ/MojoShortcuts',  _exp('Collect'), { command => 'mojo_short',   header => 'MOJOLICIOUS SHORTCUTS' } ],
 		[ '@MAXHQ/MojoConditions', _exp('Collect'), { command => 'mojo_cond',    header => 'MOJOLICIOUS CONDITIONS' } ],
 		[ '@MAXHQ/MojoHelpers',    _exp('Collect'), { command => 'mojo_helper',  header => 'MOJOLICIOUS HELPERS' } ],
-	
+
+		# Functional code
+		[ '@MAXHQ/Functions',      _exp('Collect'), { command => 'func',         header => 'FUNCTIONS'   } ],
+		
+		# Object oriented code
+		[ '@MAXHQ/RoleRequires',   _exp('Collect'), { command => 'requires',     header => 'METHODS REQUIRED BY THIS ROLE' } ],
+		[ '@MAXHQ/Attributes',     _exp('Collect'), { command => 'attr',         header => 'ATTRIBUTES'} ],
+		[ '@MAXHQ/ClassMethods',   _exp('Collect'), { command => 'class_method', header => 'CLASS METHODS' } ],
+		[ '@MAXHQ/Methods',        _exp('Collect'), { command => 'method',       header => 'METHODS' } ],
+		
+		# Footer
 	    [ '@MAXHQ/Leftovers', _exp('Leftovers'), {} ],
 	    [ '@MAXHQ/postlude',  _exp('Region'),    { region_name => 'postlude' } ],
 	    [ '@MAXHQ/Authors',   _exp('Authors'),   {} ],
@@ -138,7 +154,7 @@ Pod::Weaver::PluginBundle::Author::MAXHQ - MAXHQ's default Pod::Weaver configura
 
 =head1 VERSION
 
-version 1.000006
+version 1.001000
 
 =head1 SYNOPSIS
 
@@ -169,18 +185,9 @@ Currently this plugin bundle is equivalent to:
 	;#
 	;# functions etc.
 	;#
-	[Collect / ATTRIBUTES]
-	command = attr
+	[Collect / REX TASKS]
+	command = rex_task
 
-	[Collect / REQUIRED METHODS]
-	command = requires
-	
-	[Collect / CLASS METHODS]
-	command = class_method
-	
-	[Collect / METHODS]
-	command = method
-	
 	[Collect / MOJOLICIOUS PLUGINS]
 	command = mojo_plugin
 	
@@ -192,6 +199,21 @@ Currently this plugin bundle is equivalent to:
 	
 	[Collect / MOJOLICIOUS HELPERS]
 	command = mojo_helper
+
+	[Collect / FUNCTIONS ]
+	command = func
+
+	[Collect / ATTRIBUTES]
+	command = attr
+
+	[Collect / METHODS REQUIRED BY THIS ROLE]
+	command = requires
+	
+	[Collect / CLASS METHODS]
+	command = class_method
+	
+	[Collect / METHODS]
+	command = method
 	
 	
 	[Leftovers]
@@ -218,7 +240,7 @@ Jens Berthold <jens.berthold@jebecs.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Jens Berthold.
+This software is copyright (c) 2015 by Jens Berthold.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
